@@ -4,8 +4,8 @@ from .clique import Clique
 from .debug import Debug
 from .etd import Etd
 from .personal import Personal
-from .real_time import Real_time
+from .real_time import RealTime
 from .txpool import Txpool
-from .json_rpc import Json_rpc
-from .json_rpc_methods import Json_rpc_methods
+from .json_rpc import JsonRpc
+from .json_rpc_methods import JsonRpcMethods
 from .miner import Miner
